# Import Tools

This folder collects import tools to create publication databases.
Each of these tools must use the `publication_record_v1.csvs` format as its output.

Import tools can be categorized into four categories:
 - general search tools (find a list of publications) by quering an exsitng database
 - detailed serach tools (finds detailed information about a single publication
 - augmentation tools (finds addtional detail to a publication, e.g., references or keywords
 - transformation tools (uses one format and converts it to the SRL format, e.g., bib-import)

A tool can combine all categories.

## TODO:
 - define common imput format for each type of serach (keywords and queiries)

